@@ -42,7 +42,7 @@ make_alignment_dummies <- function(data, mapping, on, side = "left") {
   # NOTE - version testing is for the ggplot2 2.3.0 transition. Once >2.3.0 is
   # required, this can be removed
   if (utils::packageVersion("ggplot2") >= "2.2.1.9000") {
-    data <- data[substring(as.character(mapping), 2)]
+    data <- data[sapply(mapping, rlang::quo_name)]
   } else {
     data <- data[as.character(unlist(mapping))]
   }
@@ -80,10 +80,10 @@ make_alignment_dummies <- function(data, mapping, on, side = "left") {
   # NOTE - version testing is for the ggplot2 2.3.0 transition. Once >2.3.0 is
   # required, this can be removed
   if (utils::packageVersion("ggplot2") >= "2.2.1.9000") {
-    names(dummies)[names(dummies) == "y"] <- as.character(mapping$y)[2]
-    names(dummies)[names(dummies) == "start_dummy"] <- as.character(mapping$xmin)[2]
-    names(dummies)[names(dummies) == "end_dummy"] <- as.character(mapping$xmax)[2]
-    names(dummies)[names(dummies) == "id"] <- as.character(mapping$id)[2]
+    names(dummies)[names(dummies) == "y"] <- rlang::quo_name(mapping$y)
+    names(dummies)[names(dummies) == "start_dummy"] <- rlang::quo_name(mapping$xmin)
+    names(dummies)[names(dummies) == "end_dummy"] <- rlang::quo_name(mapping$xmax)
+    names(dummies)[names(dummies) == "id"] <- rlang::quo_name(mapping$id)
   } else {
     names(dummies)[names(dummies) == "y"] <- as.character(mapping$y)
     names(dummies)[names(dummies) == "start_dummy"] <- as.character(mapping$xmin)
